# scDeepJointClust:

A method that addresses the limitations by jointly training on both types of information using a deep neural network (DNN) approach. GitHub repository is
[Github-flavored Markdown](https://github.com/ZhenjiangFan/scDeepJointClust/).